@@ -23,7 +23,7 @@ import logging
 from itertools import imap
 from optparse import OptionParser
 
-from _config import logtools_config, interpolate_config
+from _config import logtools_config, interpolate_config, AttrDict
 
 __all__ = ['geoip_parse_args', 'geoip', 'geoip_main']
 
@@ -32,12 +32,15 @@ def geoip_parse_args():
     parser.add_option("-r", "--re", dest="ip_re", default=None, 
                     help="Regular expression to lookup IP in logrow")
 
+    parser.add_option("-P", "--profile", dest="profile", default='geoip',
+                      help="Configuration profile (section in configuration file)")
+    
     options, args = parser.parse_args()
     
     # Interpolate from configuration
-    options.ip_re  = interpolate_config(options.ip_re, 'geoip', 'ip_re')
+    options.ip_re  = interpolate_config(options.ip_re, options.profile, 'ip_re')
 
-    return options, args
+    return AttrDict(options.__dict__), args
 
 def geoip(options, args, fh):
     try:
@@ -56,10 +59,11 @@ def geoip(options, args, fh):
             geocode = gi.country_name_by_addr(ip)
             if geocode is None:
                 logging.debug("No Geocode for IP: %s", ip)
-            print "{0}\t{1}".format(ip, geocode)
+            yield geocode, ip, line
 
 def geoip_main():
     """Console entry-point"""
     options, args = geoip_parse_args()
-    geoip(options, args, fh=sys.stdin.readlines())
+    for geocode, ip, line in geoip(options, args, fh=sys.stdin.readlines()):
+        print "{0}\t{1}".format(ip, geocode)
     return 0
